# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.v2.tax._automatic_rule import AutomaticRule as AutomaticRule
from stripe.v2.tax._automatic_rule_service import (
    AutomaticRuleService as AutomaticRuleService,
)
