# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.delegated_checkout._requested_session import (
    RequestedSession as RequestedSession,
)
from stripe.delegated_checkout._requested_session_service import (
    RequestedSessionService as RequestedSessionService,
)
