# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.test_helpers.issuing._authorization_capture_params import (
    AuthorizationCaptureParams as AuthorizationCaptureParams,
    AuthorizationCaptureParamsPurchaseDetails as AuthorizationCaptureParamsPurchaseDetails,
    AuthorizationCaptureParamsPurchaseDetailsFleet as AuthorizationCaptureParamsPurchaseDetailsFleet,
    AuthorizationCaptureParamsPurchaseDetailsFleetCardholderPromptData as AuthorizationCaptureParamsPurchaseDetailsFleetCardholderPromptData,
    AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdown as AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdown,
    AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownFuel as AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownFuel,
    AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownNonFuel as AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownNonFuel,
    AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownTax as AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownTax,
    AuthorizationCaptureParamsPurchaseDetailsFlight as AuthorizationCaptureParamsPurchaseDetailsFlight,
    AuthorizationCaptureParamsPurchaseDetailsFlightSegment as AuthorizationCaptureParamsPurchaseDetailsFlightSegment,
    AuthorizationCaptureParamsPurchaseDetailsFuel as AuthorizationCaptureParamsPurchaseDetailsFuel,
    AuthorizationCaptureParamsPurchaseDetailsLodging as AuthorizationCaptureParamsPurchaseDetailsLodging,
    AuthorizationCaptureParamsPurchaseDetailsReceipt as AuthorizationCaptureParamsPurchaseDetailsReceipt,
)
from stripe.params.test_helpers.issuing._authorization_create_params import (
    AuthorizationCreateParams as AuthorizationCreateParams,
    AuthorizationCreateParamsAmountDetails as AuthorizationCreateParamsAmountDetails,
    AuthorizationCreateParamsFleet as AuthorizationCreateParamsFleet,
    AuthorizationCreateParamsFleetCardholderPromptData as AuthorizationCreateParamsFleetCardholderPromptData,
    AuthorizationCreateParamsFleetReportedBreakdown as AuthorizationCreateParamsFleetReportedBreakdown,
    AuthorizationCreateParamsFleetReportedBreakdownFuel as AuthorizationCreateParamsFleetReportedBreakdownFuel,
    AuthorizationCreateParamsFleetReportedBreakdownNonFuel as AuthorizationCreateParamsFleetReportedBreakdownNonFuel,
    AuthorizationCreateParamsFleetReportedBreakdownTax as AuthorizationCreateParamsFleetReportedBreakdownTax,
    AuthorizationCreateParamsFuel as AuthorizationCreateParamsFuel,
    AuthorizationCreateParamsMerchantData as AuthorizationCreateParamsMerchantData,
    AuthorizationCreateParamsNetworkData as AuthorizationCreateParamsNetworkData,
    AuthorizationCreateParamsRiskAssessment as AuthorizationCreateParamsRiskAssessment,
    AuthorizationCreateParamsRiskAssessmentCardTestingRisk as AuthorizationCreateParamsRiskAssessmentCardTestingRisk,
    AuthorizationCreateParamsRiskAssessmentMerchantDisputeRisk as AuthorizationCreateParamsRiskAssessmentMerchantDisputeRisk,
    AuthorizationCreateParamsVerificationData as AuthorizationCreateParamsVerificationData,
    AuthorizationCreateParamsVerificationDataAuthenticationExemption as AuthorizationCreateParamsVerificationDataAuthenticationExemption,
    AuthorizationCreateParamsVerificationDataThreeDSecure as AuthorizationCreateParamsVerificationDataThreeDSecure,
)
from stripe.params.test_helpers.issuing._authorization_expire_params import (
    AuthorizationExpireParams as AuthorizationExpireParams,
)
from stripe.params.test_helpers.issuing._authorization_finalize_amount_params import (
    AuthorizationFinalizeAmountParams as AuthorizationFinalizeAmountParams,
    AuthorizationFinalizeAmountParamsFleet as AuthorizationFinalizeAmountParamsFleet,
    AuthorizationFinalizeAmountParamsFleetCardholderPromptData as AuthorizationFinalizeAmountParamsFleetCardholderPromptData,
    AuthorizationFinalizeAmountParamsFleetReportedBreakdown as AuthorizationFinalizeAmountParamsFleetReportedBreakdown,
    AuthorizationFinalizeAmountParamsFleetReportedBreakdownFuel as AuthorizationFinalizeAmountParamsFleetReportedBreakdownFuel,
    AuthorizationFinalizeAmountParamsFleetReportedBreakdownNonFuel as AuthorizationFinalizeAmountParamsFleetReportedBreakdownNonFuel,
    AuthorizationFinalizeAmountParamsFleetReportedBreakdownTax as AuthorizationFinalizeAmountParamsFleetReportedBreakdownTax,
    AuthorizationFinalizeAmountParamsFuel as AuthorizationFinalizeAmountParamsFuel,
)
from stripe.params.test_helpers.issuing._authorization_increment_params import (
    AuthorizationIncrementParams as AuthorizationIncrementParams,
)
from stripe.params.test_helpers.issuing._authorization_respond_params import (
    AuthorizationRespondParams as AuthorizationRespondParams,
)
from stripe.params.test_helpers.issuing._authorization_reverse_params import (
    AuthorizationReverseParams as AuthorizationReverseParams,
)
from stripe.params.test_helpers.issuing._card_deliver_card_params import (
    CardDeliverCardParams as CardDeliverCardParams,
)
from stripe.params.test_helpers.issuing._card_fail_card_params import (
    CardFailCardParams as CardFailCardParams,
)
from stripe.params.test_helpers.issuing._card_return_card_params import (
    CardReturnCardParams as CardReturnCardParams,
)
from stripe.params.test_helpers.issuing._card_ship_card_params import (
    CardShipCardParams as CardShipCardParams,
)
from stripe.params.test_helpers.issuing._card_submit_card_params import (
    CardSubmitCardParams as CardSubmitCardParams,
)
from stripe.params.test_helpers.issuing._personalization_design_activate_params import (
    PersonalizationDesignActivateParams as PersonalizationDesignActivateParams,
)
from stripe.params.test_helpers.issuing._personalization_design_deactivate_params import (
    PersonalizationDesignDeactivateParams as PersonalizationDesignDeactivateParams,
)
from stripe.params.test_helpers.issuing._personalization_design_reject_params import (
    PersonalizationDesignRejectParams as PersonalizationDesignRejectParams,
    PersonalizationDesignRejectParamsRejectionReasons as PersonalizationDesignRejectParamsRejectionReasons,
)
from stripe.params.test_helpers.issuing._transaction_create_force_capture_params import (
    TransactionCreateForceCaptureParams as TransactionCreateForceCaptureParams,
    TransactionCreateForceCaptureParamsMerchantData as TransactionCreateForceCaptureParamsMerchantData,
    TransactionCreateForceCaptureParamsPurchaseDetails as TransactionCreateForceCaptureParamsPurchaseDetails,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleet as TransactionCreateForceCaptureParamsPurchaseDetailsFleet,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleetCardholderPromptData as TransactionCreateForceCaptureParamsPurchaseDetailsFleetCardholderPromptData,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdown as TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdown,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownFuel as TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownFuel,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownNonFuel as TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownNonFuel,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownTax as TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownTax,
    TransactionCreateForceCaptureParamsPurchaseDetailsFlight as TransactionCreateForceCaptureParamsPurchaseDetailsFlight,
    TransactionCreateForceCaptureParamsPurchaseDetailsFlightSegment as TransactionCreateForceCaptureParamsPurchaseDetailsFlightSegment,
    TransactionCreateForceCaptureParamsPurchaseDetailsFuel as TransactionCreateForceCaptureParamsPurchaseDetailsFuel,
    TransactionCreateForceCaptureParamsPurchaseDetailsLodging as TransactionCreateForceCaptureParamsPurchaseDetailsLodging,
    TransactionCreateForceCaptureParamsPurchaseDetailsReceipt as TransactionCreateForceCaptureParamsPurchaseDetailsReceipt,
)
from stripe.params.test_helpers.issuing._transaction_create_unlinked_refund_params import (
    TransactionCreateUnlinkedRefundParams as TransactionCreateUnlinkedRefundParams,
    TransactionCreateUnlinkedRefundParamsMerchantData as TransactionCreateUnlinkedRefundParamsMerchantData,
    TransactionCreateUnlinkedRefundParamsPurchaseDetails as TransactionCreateUnlinkedRefundParamsPurchaseDetails,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleet as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleet,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetCardholderPromptData as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetCardholderPromptData,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdown as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdown,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownFuel as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownFuel,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownNonFuel as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownNonFuel,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownTax as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownTax,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFlight as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFlight,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFlightSegment as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFlightSegment,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFuel as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFuel,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsLodging as TransactionCreateUnlinkedRefundParamsPurchaseDetailsLodging,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsReceipt as TransactionCreateUnlinkedRefundParamsPurchaseDetailsReceipt,
)
from stripe.params.test_helpers.issuing._transaction_refund_params import (
    TransactionRefundParams as TransactionRefundParams,
)
