# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.v2.billing.rate_cards._rate_service import (
    RateService as RateService,
)
from stripe.v2.billing.rate_cards._version_service import (
    VersionService as VersionService,
)
