# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing_extensions import TypedDict


class AutomaticRuleUpdateParams(TypedDict):
    tax_code: str
    """
    The TaxCode object to be used for automatic tax calculations.
    """
