# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.v2.core.accounts._person_create_params import (
    PersonCreateParams as PersonCreateParams,
    PersonCreateParamsAdditionalAddress as PersonCreateParamsAdditionalAddress,
    PersonCreateParamsAdditionalName as PersonCreateParamsAdditionalName,
    PersonCreateParamsAdditionalTermsOfService as PersonCreateParamsAdditionalTermsOfService,
    PersonCreateParamsAdditionalTermsOfServiceAccount as PersonCreateParamsAdditionalTermsOfServiceAccount,
    PersonCreateParamsAddress as PersonCreateParamsAddress,
    PersonCreateParamsDateOfBirth as PersonCreateParamsDateOfBirth,
    PersonCreateParamsDocuments as PersonCreateParamsDocuments,
    PersonCreateParamsDocumentsCompanyAuthorization as PersonCreateParamsDocumentsCompanyAuthorization,
    PersonCreateParamsDocumentsPassport as PersonCreateParamsDocumentsPassport,
    PersonCreateParamsDocumentsPrimaryVerification as PersonCreateParamsDocumentsPrimaryVerification,
    PersonCreateParamsDocumentsPrimaryVerificationFrontBack as PersonCreateParamsDocumentsPrimaryVerificationFrontBack,
    PersonCreateParamsDocumentsSecondaryVerification as PersonCreateParamsDocumentsSecondaryVerification,
    PersonCreateParamsDocumentsSecondaryVerificationFrontBack as PersonCreateParamsDocumentsSecondaryVerificationFrontBack,
    PersonCreateParamsDocumentsVisa as PersonCreateParamsDocumentsVisa,
    PersonCreateParamsIdNumber as PersonCreateParamsIdNumber,
    PersonCreateParamsRelationship as PersonCreateParamsRelationship,
    PersonCreateParamsScriptAddresses as PersonCreateParamsScriptAddresses,
    PersonCreateParamsScriptAddressesKana as PersonCreateParamsScriptAddressesKana,
    PersonCreateParamsScriptAddressesKanji as PersonCreateParamsScriptAddressesKanji,
    PersonCreateParamsScriptNames as PersonCreateParamsScriptNames,
    PersonCreateParamsScriptNamesKana as PersonCreateParamsScriptNamesKana,
    PersonCreateParamsScriptNamesKanji as PersonCreateParamsScriptNamesKanji,
)
from stripe.params.v2.core.accounts._person_delete_params import (
    PersonDeleteParams as PersonDeleteParams,
)
from stripe.params.v2.core.accounts._person_list_params import (
    PersonListParams as PersonListParams,
)
from stripe.params.v2.core.accounts._person_retrieve_params import (
    PersonRetrieveParams as PersonRetrieveParams,
)
from stripe.params.v2.core.accounts._person_update_params import (
    PersonUpdateParams as PersonUpdateParams,
    PersonUpdateParamsAdditionalAddress as PersonUpdateParamsAdditionalAddress,
    PersonUpdateParamsAdditionalName as PersonUpdateParamsAdditionalName,
    PersonUpdateParamsAdditionalTermsOfService as PersonUpdateParamsAdditionalTermsOfService,
    PersonUpdateParamsAdditionalTermsOfServiceAccount as PersonUpdateParamsAdditionalTermsOfServiceAccount,
    PersonUpdateParamsAddress as PersonUpdateParamsAddress,
    PersonUpdateParamsDateOfBirth as PersonUpdateParamsDateOfBirth,
    PersonUpdateParamsDocuments as PersonUpdateParamsDocuments,
    PersonUpdateParamsDocumentsCompanyAuthorization as PersonUpdateParamsDocumentsCompanyAuthorization,
    PersonUpdateParamsDocumentsPassport as PersonUpdateParamsDocumentsPassport,
    PersonUpdateParamsDocumentsPrimaryVerification as PersonUpdateParamsDocumentsPrimaryVerification,
    PersonUpdateParamsDocumentsPrimaryVerificationFrontBack as PersonUpdateParamsDocumentsPrimaryVerificationFrontBack,
    PersonUpdateParamsDocumentsSecondaryVerification as PersonUpdateParamsDocumentsSecondaryVerification,
    PersonUpdateParamsDocumentsSecondaryVerificationFrontBack as PersonUpdateParamsDocumentsSecondaryVerificationFrontBack,
    PersonUpdateParamsDocumentsVisa as PersonUpdateParamsDocumentsVisa,
    PersonUpdateParamsIdNumber as PersonUpdateParamsIdNumber,
    PersonUpdateParamsRelationship as PersonUpdateParamsRelationship,
    PersonUpdateParamsScriptAddresses as PersonUpdateParamsScriptAddresses,
    PersonUpdateParamsScriptAddressesKana as PersonUpdateParamsScriptAddressesKana,
    PersonUpdateParamsScriptAddressesKanji as PersonUpdateParamsScriptAddressesKanji,
    PersonUpdateParamsScriptNames as PersonUpdateParamsScriptNames,
    PersonUpdateParamsScriptNamesKana as PersonUpdateParamsScriptNamesKana,
    PersonUpdateParamsScriptNamesKanji as PersonUpdateParamsScriptNamesKanji,
)
