# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.v2.tax._automatic_rule_create_params import (
    AutomaticRuleCreateParams as AutomaticRuleCreateParams,
)
from stripe.params.v2.tax._automatic_rule_deactivate_params import (
    AutomaticRuleDeactivateParams as AutomaticRuleDeactivateParams,
)
from stripe.params.v2.tax._automatic_rule_find_params import (
    AutomaticRuleFindParams as AutomaticRuleFindParams,
)
from stripe.params.v2.tax._automatic_rule_retrieve_params import (
    AutomaticRuleRetrieveParams as AutomaticRuleRetrieveParams,
)
from stripe.params.v2.tax._automatic_rule_update_params import (
    AutomaticRuleUpdateParams as AutomaticRuleUpdateParams,
)
