# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.v2.test_helpers._financial_address_credit_params import (
    FinancialAddressCreditParams as FinancialAddressCreditParams,
)
from stripe.params.v2.test_helpers._financial_address_generate_microdeposits_params import (
    FinancialAddressGenerateMicrodepositsParams as FinancialAddressGenerateMicrodepositsParams,
)
from stripe.params.v2.test_helpers._money_management_recipient_verifications_params import (
    MoneyManagementRecipientVerificationsParams as MoneyManagementRecipientVerificationsParams,
)
