# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing_extensions import TypedDict


class AutomaticRuleFindParams(TypedDict):
    billable_item: str
    """
    The BillableItem ID to search by.
    """
