# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.v2.billing.collection_settings._version_list_params import (
    VersionListParams as VersionListParams,
)
from stripe.params.v2.billing.collection_settings._version_retrieve_params import (
    VersionRetrieveParams as VersionRetrieveParams,
)
